summaryrefslogtreecommitdiffhomepage
path: root/docker/entrypoint.dev.sh
diff options
context:
space:
mode:
Diffstat (limited to 'docker/entrypoint.dev.sh')
-rw-r--r--docker/entrypoint.dev.sh6
1 files changed, 4 insertions, 2 deletions
diff --git a/docker/entrypoint.dev.sh b/docker/entrypoint.dev.sh
index 8378585..bbde09a 100644
--- a/docker/entrypoint.dev.sh
+++ b/docker/entrypoint.dev.sh
@@ -40,8 +40,10 @@ if [ -d /app/node_modules ]; then
chown -R "$HOST_UID:$HOST_GID" /app/node_modules
fi
-# Install/update dependencies as the target user
-su -s /bin/bash - "$USER_NAME" -c "export HOME=$USER_HOME && cd /app && bun install"
+# Install/update dependencies as the target user (skip with SKIP_INSTALL=1)
+if [ "${SKIP_INSTALL:-}" != "1" ]; then
+ su -s /bin/bash - "$USER_NAME" -c "export HOME=$USER_HOME && cd /app && bun install"
+fi
# Execute the main command as the target user
exec su -s /bin/bash - "$USER_NAME" -c "export HOME=$USER_HOME && cd /app && exec $*"